library nb_utils;

import 'package:flutter/material.dart';
import 'package:nb_utils/src/colors.dart';

export 'src/colors.dart';
export 'src/livestream.dart';
export 'src/scroll_extensions.dart';
export 'src/string_extensions.dart';
export 'src/text_extensions.dart';
export 'src/time_formatter.dart';
export 'src/widget_extensions.dart';

/// Go back to previous screen.
finish(context) {
  Navigator.pop(context);
}

/// Go to new screen with provided screen tag.
///
/// ```dart
/// launchNewScreen(context, '/HomePage');
/// ```
launchNewScreen(context, tag) {
  Navigator.of(context).pushNamed(tag);
}

/// Removes all previous screens from the back stack and redirect to new screen with provided screen tag
///
/// ```dart
/// launchNewScreenWithNewTask(context, '/HomePage');
/// ```
launchNewScreenWithNewTask(context, tag) {
  Navigator.of(context).pushNamedAndRemoveUntil(tag, (r) => false);
}

/// Returns Color from hex String.
///
/// ```dart
/// Color color = getColorFromHex('#E5E5E5');
/// ```
Color getColorFromHex(String hexColor) {
  try {
    hexColor = hexColor.toUpperCase().replaceAll('#', '');
    if (hexColor.length == 6) {
      hexColor = 'FF' + hexColor;
    }
    return Color(int.parse(hexColor, radix: 16));
  } catch (e) {
    print(e);
    return Colors.white;
  }
}

/// Hide soft keyboard
hideKeyboard(context) {
  FocusScope.of(context).requestFocus(FocusNode());
}

mixin AfterLayoutMixin<T extends StatefulWidget> on State<T> {
  @override
  void initState() {
    super.initState();
    WidgetsBinding.instance.addPostFrameCallback((_) => afterFirstLayout(context));
  }

  void afterFirstLayout(BuildContext context);
}

extension IntExtensions on int {
  /// Validate given int is not null and returns given value if null.
  int validate({int value = 0}) {
    if (this == null) {
      return value;
    } else
      return this;
  }
}

extension DoubleExtensions on double {
  /// Validate given double is not null and returns given value if null.
  double validate({double value = 0.0}) {
    if (this == null) {
      return value;
    } else
      return this;
  }
}

extension BooleanExtensions on bool {
  /// Validate given bool is not null and returns given value if null.
  bool validate({bool value = false}) {
    if (this == null) {
      return value;
    } else
      return this;
  }
}

// Styles

boldTextStyle({int size = 18, Color color = textPrimaryColor}) {
  return TextStyle(
    fontSize: size.toDouble(),
    color: color,
    fontWeight: FontWeight.bold,
  );
}

//
primaryTextStyle({int size = 18, Color color = textPrimaryColor}) {
  return TextStyle(
    fontSize: size.toDouble(),
    color: color,
  );
}

//
secondaryTextStyle({int size = 16, Color color = textSecondaryColor}) {
  return TextStyle(
    fontSize: size.toDouble(),
    color: color,
  );
}

//
